@@ -11,22 +11,22 @@ def populate_userkeys(apps, schema_editor):
     UserKey = apps.get_model('netbox_secrets', 'UserKey')
 
     # Retrieve the necessary data from SecretStore objects
-    userkeys = UserKeyOld.objects.values(
-        'id', 'created', 'last_updated', 'user', 'public_key', 'master_key_cipher'
-    )
+    userkeys = UserKeyOld.objects.values('id', 'created', 'last_updated', 'user', 'public_key', 'master_key_cipher')
 
     # Queue UserKeys to be created
     userkeys_to_create = []
     userkey_count = userkeys.count()
     for i, userkey in enumerate(userkeys, start=1):
-        userkeys_to_create.append(UserKey(
-            id=userkey['id'],
-            created=userkey['created'],
-            last_updated=userkey['last_updated'],
-            user_id=userkey['user'],
-            public_key=userkey['public_key'],
-            master_key_cipher=userkey['master_key_cipher'],
-        ))
+        userkeys_to_create.append(
+            UserKey(
+                id=userkey['id'],
+                created=userkey['created'],
+                last_updated=userkey['last_updated'],
+                user_id=userkey['user'],
+                public_key=userkey['public_key'],
+                master_key_cipher=userkey['master_key_cipher'],
+            ),
+        )
 
     # Bulk create the userkey objects
     UserKey.objects.bulk_create(userkeys_to_create, batch_size=100)
@@ -38,8 +38,5 @@ class Migration(migrations.Migration):
     ]
 
     operations = [
-        migrations.RunPython(
-            code=populate_userkeys,
-            reverse_code=migrations.RunPython.noop
-        ),
+        migrations.RunPython(code=populate_userkeys, reverse_code=migrations.RunPython.noop),
     ]
