@@ -1,9 +1,9 @@
 from .crypto import *
 from .helpers import *
 
-__all__ = (
+__all__ = [
     'encrypt_master_key',
     'decrypt_master_key',
     'generate_random_key',
     'get_session_key',
-)
+]
